@@ -1,20 +1,20 @@
 # ============================================================================#
 # BETA DISTRIBUTION (gamma, delta+1 Parameterization)
 # ============================================================================#
-# 
+#
 # Wrapper functions for the Beta distribution using the parameterization
 # common in the Generalized Kumaraswamy family.
-# 
+#
 # IMPORTANT PARAMETERIZATION NOTE:
 # This implementation uses gamma (γ) and delta (δ) parameters, where:
 #   shape1 = gamma
 #   shape2 = delta + 1
-# 
+#
 # This differs from stats::dbeta(x, shape1, shape2) where shape2 is used directly.
-# 
+#
 # Relationship to stats::Beta:
 #   dbeta_(x, gamma, delta) ≡ dbeta(x, shape1 = gamma, shape2 = delta + 1)
-# 
+#
 # C++ implementations are in src/beta.cpp
 #
 # Functions:
@@ -111,8 +111,10 @@
 #' print(paste("Max difference vs stats::dbeta:", max(abs(densities - densities_stats))))
 #'
 #' # Compare with dgkw setting alpha=1, beta=1, lambda=1
-#' densities_gkw <- dgkw(x_vals, alpha = 1.0, beta = 1.0, gamma = gamma_par,
-#'                       delta = delta_par, lambda = 1.0)
+#' densities_gkw <- dgkw(x_vals,
+#'   alpha = 1.0, beta = 1.0, gamma = gamma_par,
+#'   delta = delta_par, lambda = 1.0
+#' )
 #' print(paste("Max difference vs dgkw:", max(abs(densities - densities_gkw))))
 #'
 #' # Compare with dmc setting lambda=1
@@ -127,12 +129,15 @@
 #' # Plot the density
 #' curve_x <- seq(0.001, 0.999, length.out = 200)
 #' curve_y <- dbeta_(curve_x, gamma = 2, delta = 3) # Beta(2, 4)
-#' plot(curve_x, curve_y, type = "l", main = "Beta(2, 4) Density via dbeta_",
-#'      xlab = "x", ylab = "f(x)", col = "blue")
-#' curve(stats::dbeta(x, 2, 4), add=TRUE, col="red", lty=2)
-#' legend("topright", legend=c("dbeta_(gamma=2, delta=3)", "stats::dbeta(shape1=2, shape2=4)"),
-#'        col=c("blue", "red"), lty=c(1,2), bty="n")
-#'
+#' plot(curve_x, curve_y,
+#'   type = "l", main = "Beta(2, 4) Density via dbeta_",
+#'   xlab = "x", ylab = "f(x)", col = "blue"
+#' )
+#' curve(stats::dbeta(x, 2, 4), add = TRUE, col = "red", lty = 2)
+#' legend("topright",
+#'   legend = c("dbeta_(gamma=2, delta=3)", "stats::dbeta(shape1=2, shape2=4)"),
+#'   col = c("blue", "red"), lty = c(1, 2), bty = "n"
+#' )
 #' }
 #'
 #' @export
@@ -150,7 +155,7 @@ dbeta_ <- function(x, gamma = 1, delta = 0, log = FALSE) {
   if (!is.logical(log) || length(log) != 1) {
     stop("'log' must be a single logical value")
   }
-  
+
   # Informative warning about parameterization
   if (getOption("gkwdist.warn.beta.param", default = FALSE)) {
     message(
@@ -159,14 +164,15 @@ dbeta_ <- function(x, gamma = 1, delta = 0, log = FALSE) {
       "Set options(gkwdist.warn.beta.param=FALSE) to suppress this message."
     )
   }
-  
+
   # Call C++ implementation
-  .Call("_gkwdist_dbeta_", 
-        as.numeric(x), 
-        as.numeric(gamma), 
-        as.numeric(delta), 
-        as.logical(log),
-        PACKAGE = "gkwdist")
+  .Call("_gkwdist_dbeta_",
+    as.numeric(x),
+    as.numeric(gamma),
+    as.numeric(delta),
+    as.logical(log),
+    PACKAGE = "gkwdist"
+  )
 }
 
 
@@ -253,8 +259,10 @@ dbeta_ <- function(x, gamma = 1, delta = 0, log = FALSE) {
 #' print(paste("Max difference vs stats::pbeta:", max(abs(probs - probs_stats))))
 #'
 #' # Compare with pgkw setting alpha=1, beta=1, lambda=1
-#' probs_gkw <- pgkw(q_vals, alpha = 1.0, beta = 1.0, gamma = gamma_par,
-#'                   delta = delta_par, lambda = 1.0)
+#' probs_gkw <- pgkw(q_vals,
+#'   alpha = 1.0, beta = 1.0, gamma = gamma_par,
+#'   delta = delta_par, lambda = 1.0
+#' )
 #' print(paste("Max difference vs pgkw:", max(abs(probs - probs_gkw))))
 #'
 #' # Compare with pmc setting lambda=1
@@ -274,12 +282,15 @@ dbeta_ <- function(x, gamma = 1, delta = 0, log = FALSE) {
 #' # Plot the CDF
 #' curve_q <- seq(0.001, 0.999, length.out = 200)
 #' curve_p <- pbeta_(curve_q, gamma = 2, delta = 3) # Beta(2, 4)
-#' plot(curve_q, curve_p, type = "l", main = "Beta(2, 4) CDF via pbeta_",
-#'      xlab = "q", ylab = "F(q)", col = "blue")
-#' curve(stats::pbeta(x, 2, 4), add=TRUE, col="red", lty=2)
-#' legend("bottomright", legend=c("pbeta_(gamma=2, delta=3)", "stats::pbeta(shape1=2, shape2=4)"),
-#'        col=c("blue", "red"), lty=c(1,2), bty="n")
-#'
+#' plot(curve_q, curve_p,
+#'   type = "l", main = "Beta(2, 4) CDF via pbeta_",
+#'   xlab = "q", ylab = "F(q)", col = "blue"
+#' )
+#' curve(stats::pbeta(x, 2, 4), add = TRUE, col = "red", lty = 2)
+#' legend("bottomright",
+#'   legend = c("pbeta_(gamma=2, delta=3)", "stats::pbeta(shape1=2, shape2=4)"),
+#'   col = c("blue", "red"), lty = c(1, 2), bty = "n"
+#' )
 #' }
 #'
 #' @export
@@ -300,15 +311,16 @@ pbeta_ <- function(q, gamma = 1, delta = 0, lower.tail = TRUE, log.p = FALSE) {
   if (!is.logical(log.p) || length(log.p) != 1) {
     stop("'log.p' must be a single logical value")
   }
-  
+
   # Call C++ implementation
-  .Call("_gkwdist_pbeta_", 
-        as.numeric(q), 
-        as.numeric(gamma), 
-        as.numeric(delta), 
-        as.logical(lower.tail),
-        as.logical(log.p),
-        PACKAGE = "gkwdist")
+  .Call("_gkwdist_pbeta_",
+    as.numeric(q),
+    as.numeric(gamma),
+    as.numeric(delta),
+    as.logical(lower.tail),
+    as.logical(log.p),
+    PACKAGE = "gkwdist"
+  )
 }
 
 
@@ -403,8 +415,10 @@ pbeta_ <- function(q, gamma = 1, delta = 0, lower.tail = TRUE, log.p = FALSE) {
 #' print(paste("Max difference vs stats::qbeta:", max(abs(quantiles - quantiles_stats))))
 #'
 #' # Compare with qgkw setting alpha=1, beta=1, lambda=1
-#' quantiles_gkw <- qgkw(p_vals, alpha = 1.0, beta = 1.0, gamma = gamma_par,
-#'                       delta = delta_par, lambda = 1.0)
+#' quantiles_gkw <- qgkw(p_vals,
+#'   alpha = 1.0, beta = 1.0, gamma = gamma_par,
+#'   delta = delta_par, lambda = 1.0
+#' )
 #' print(paste("Max difference vs qgkw:", max(abs(quantiles - quantiles_gkw))))
 #'
 #' # Compare with qmc setting lambda=1
@@ -432,7 +446,6 @@ pbeta_ <- function(q, gamma = 1, delta = 0, lower.tail = TRUE, log.p = FALSE) {
 #' # Boundary conditions
 #' print(qbeta_(c(0, 1), gamma_par, delta_par)) # Should be 0, 1
 #' print(qbeta_(c(-Inf, 0), gamma_par, delta_par, log.p = TRUE)) # Should be 0, 1
-#'
 #' }
 #'
 #' @export
@@ -453,20 +466,21 @@ qbeta_ <- function(p, gamma = 1, delta = 0, lower.tail = TRUE, log.p = FALSE) {
   if (!is.logical(log.p) || length(log.p) != 1) {
     stop("'log.p' must be a single logical value")
   }
-  
+
   # Additional validation for probabilities
   if (!log.p && any(p < 0 | p > 1, na.rm = TRUE)) {
     warning("'p' values outside [0, 1] will produce NaN")
   }
-  
+
   # Call C++ implementation
-  .Call("_gkwdist_qbeta_", 
-        as.numeric(p), 
-        as.numeric(gamma), 
-        as.numeric(delta), 
-        as.logical(lower.tail),
-        as.logical(log.p),
-        PACKAGE = "gkwdist")
+  .Call("_gkwdist_qbeta_",
+    as.numeric(p),
+    as.numeric(gamma),
+    as.numeric(delta),
+    as.logical(lower.tail),
+    as.logical(log.p),
+    PACKAGE = "gkwdist"
+  )
 }
 
 
@@ -548,17 +562,19 @@ qbeta_ <- function(p, gamma = 1, delta = 0, lower.tail = TRUE, log.p = FALSE) {
 #' # Compare with stats::rbeta
 #' x_sample_stats <- stats::rbeta(1000, shape1 = shape1, shape2 = shape2)
 #' # Visually compare histograms or QQ-plots
-#' hist(x_sample, main="rbeta_ Sample", freq=FALSE, breaks=30)
-#' curve(dbeta_(x, gamma_par, delta_par), add=TRUE, col="red", lwd=2)
-#' hist(x_sample_stats, main="stats::rbeta Sample", freq=FALSE, breaks=30)
-#' curve(stats::dbeta(x, shape1, shape2), add=TRUE, col="blue", lwd=2)
+#' hist(x_sample, main = "rbeta_ Sample", freq = FALSE, breaks = 30)
+#' curve(dbeta_(x, gamma_par, delta_par), add = TRUE, col = "red", lwd = 2)
+#' hist(x_sample_stats, main = "stats::rbeta Sample", freq = FALSE, breaks = 30)
+#' curve(stats::dbeta(x, shape1, shape2), add = TRUE, col = "blue", lwd = 2)
 #' # Compare summary stats (should be similar due to randomness)
 #' print(summary(x_sample))
 #' print(summary(x_sample_stats))
 #'
 #' # Compare summary stats with rgkw(alpha=1, beta=1, lambda=1)
-#' x_sample_gkw <- rgkw(1000, alpha = 1.0, beta = 1.0, gamma = gamma_par,
-#'                      delta = delta_par, lambda = 1.0)
+#' x_sample_gkw <- rgkw(1000,
+#'   alpha = 1.0, beta = 1.0, gamma = gamma_par,
+#'   delta = delta_par, lambda = 1.0
+#' )
 #' print("Summary stats for rgkw(a=1,b=1,l=1) sample:")
 #' print(summary(x_sample_gkw))
 #'
@@ -566,7 +582,6 @@ qbeta_ <- function(p, gamma = 1, delta = 0, lower.tail = TRUE, log.p = FALSE) {
 #' x_sample_mc <- rmc(1000, gamma = gamma_par, delta = delta_par, lambda = 1.0)
 #' print("Summary stats for rmc(l=1) sample:")
 #' print(summary(x_sample_mc))
-#'
 #' }
 #'
 #' @export
@@ -577,20 +592,21 @@ rbeta_ <- function(n, gamma = 1, delta = 0) {
     stop("'n' must be a positive integer")
   }
   n <- as.integer(n)
-  
+
   if (!is.numeric(gamma) || any(gamma <= 0, na.rm = TRUE)) {
     stop("'gamma' must be positive (gamma > 0)")
   }
   if (!is.numeric(delta) || any(delta < 0, na.rm = TRUE)) {
     stop("'delta' must be non-negative (delta >= 0)")
   }
-  
+
   # Call C++ implementation
-  .Call("_gkwdist_rbeta_", 
-        as.integer(n), 
-        as.numeric(gamma), 
-        as.numeric(delta),
-        PACKAGE = "gkwdist")
+  .Call("_gkwdist_rbeta_",
+    as.integer(n),
+    as.numeric(gamma),
+    as.numeric(delta),
+    PACKAGE = "gkwdist"
+  )
 }
 
 
@@ -664,24 +680,24 @@ rbeta_ <- function(n, gamma = 1, delta = 0) {
 #' @examples
 #' \donttest{
 #' ## Example 1: Basic Log-Likelihood Evaluation
-#' 
+#'
 #' # Generate sample data
 #' set.seed(123)
 #' n <- 1000
 #' true_params <- c(gamma = 2.0, delta = 3.0)
 #' data <- rbeta_(n, gamma = true_params[1], delta = true_params[2])
-#' 
+#'
 #' # Evaluate negative log-likelihood at true parameters
 #' nll_true <- llbeta(par = true_params, data = data)
 #' cat("Negative log-likelihood at true parameters:", nll_true, "\n")
-#' 
+#'
 #' # Evaluate at different parameter values
 #' test_params <- rbind(
 #'   c(1.5, 2.5),
 #'   c(2.0, 3.0),
 #'   c(2.5, 3.5)
 #' )
-#' 
+#'
 #' nll_values <- apply(test_params, 1, function(p) llbeta(p, data))
 #' results <- data.frame(
 #'   Gamma = test_params[, 1],
@@ -689,10 +705,10 @@ rbeta_ <- function(n, gamma = 1, delta = 0) {
 #'   NegLogLik = nll_values
 #' )
 #' print(results, digits = 4)
-#' 
-#' 
+#'
+#'
 #' ## Example 2: Maximum Likelihood Estimation
-#' 
+#'
 #' # Optimization using L-BFGS-B with bounds
 #' fit <- optim(
 #'   par = c(1.5, 2.5),
@@ -704,11 +720,11 @@ rbeta_ <- function(n, gamma = 1, delta = 0) {
 #'   upper = c(100, 100),
 #'   hessian = TRUE
 #' )
-#' 
+#'
 #' mle <- fit$par
 #' names(mle) <- c("gamma", "delta")
 #' se <- sqrt(diag(solve(fit$hessian)))
-#' 
+#'
 #' results <- data.frame(
 #'   Parameter = c("gamma", "delta"),
 #'   True = true_params,
@@ -718,22 +734,26 @@ rbeta_ <- function(n, gamma = 1, delta = 0) {
 #'   CI_Upper = mle + 1.96 * se
 #' )
 #' print(results, digits = 4)
-#' 
-#' cat(sprintf("\nMLE corresponds approx to Beta(%.2f, %.2f)\n",
-#'     mle[1], mle[2] + 1))
-#' cat("True corresponds to Beta(%.2f, %.2f)\n",
-#'     true_params[1], true_params[2] + 1)
-#' 
+#'
+#' cat(sprintf(
+#'   "\nMLE corresponds approx to Beta(%.2f, %.2f)\n",
+#'   mle[1], mle[2] + 1
+#' ))
+#' cat(
+#'   "True corresponds to Beta(%.2f, %.2f)\n",
+#'   true_params[1], true_params[2] + 1
+#' )
+#'
 #' cat("\nNegative log-likelihood at MLE:", fit$value, "\n")
 #' cat("AIC:", 2 * fit$value + 2 * length(mle), "\n")
 #' cat("BIC:", 2 * fit$value + length(mle) * log(n), "\n")
-#' 
-#' 
+#'
+#'
 #' ## Example 3: Comparing Optimization Methods
-#' 
+#'
 #' methods <- c("BFGS", "L-BFGS-B", "Nelder-Mead", "CG")
 #' start_params <- c(1.5, 2.5)
-#' 
+#'
 #' comparison <- data.frame(
 #'   Method = character(),
 #'   Gamma = numeric(),
@@ -742,7 +762,7 @@ rbeta_ <- function(n, gamma = 1, delta = 0) {
 #'   Convergence = integer(),
 #'   stringsAsFactors = FALSE
 #' )
-#' 
+#'
 #' for (method in methods) {
 #'   if (method %in% c("BFGS", "CG")) {
 #'     fit_temp <- optim(
@@ -770,7 +790,7 @@ rbeta_ <- function(n, gamma = 1, delta = 0) {
 #'       method = method
 #'     )
 #'   }
-#' 
+#'
 #'   comparison <- rbind(comparison, data.frame(
 #'     Method = method,
 #'     Gamma = fit_temp$par[1],
@@ -780,19 +800,19 @@ rbeta_ <- function(n, gamma = 1, delta = 0) {
 #'     stringsAsFactors = FALSE
 #'   ))
 #' }
-#' 
+#'
 #' print(comparison, digits = 4, row.names = FALSE)
-#' 
-#' 
+#'
+#'
 #' ## Example 4: Likelihood Ratio Test
-#' 
+#'
 #' # Test H0: delta = 3 vs H1: delta free
 #' loglik_full <- -fit$value
-#' 
+#'
 #' restricted_ll <- function(params_restricted, data, delta_fixed) {
 #'   llbeta(par = c(params_restricted[1], delta_fixed), data = data)
 #' }
-#' 
+#'
 #' fit_restricted <- optim(
 #'   par = mle[1],
 #'   fn = restricted_ll,
@@ -800,22 +820,22 @@ rbeta_ <- function(n, gamma = 1, delta = 0) {
 #'   delta_fixed = 3,
 #'   method = "BFGS"
 #' )
-#' 
+#'
 #' loglik_restricted <- -fit_restricted$value
 #' lr_stat <- 2 * (loglik_full - loglik_restricted)
 #' p_value <- pchisq(lr_stat, df = 1, lower.tail = FALSE)
-#' 
+#'
 #' cat("LR Statistic:", round(lr_stat, 4), "\n")
 #' cat("P-value:", format.pval(p_value, digits = 4), "\n")
-#' 
-#' 
+#'
+#'
 #' ## Example 5: Univariate Profile Likelihoods
-#' 
+#'
 #' # Profile for gamma
 #' gamma_grid <- seq(mle[1] - 1.5, mle[1] + 1.5, length.out = 50)
 #' gamma_grid <- gamma_grid[gamma_grid > 0]
 #' profile_ll_gamma <- numeric(length(gamma_grid))
-#' 
+#'
 #' for (i in seq_along(gamma_grid)) {
 #'   profile_fit <- optim(
 #'     par = mle[2],
@@ -824,12 +844,12 @@ rbeta_ <- function(n, gamma = 1, delta = 0) {
 #'   )
 #'   profile_ll_gamma[i] <- -profile_fit$value
 #' }
-#' 
+#'
 #' # Profile for delta
 #' delta_grid <- seq(mle[2] - 1.5, mle[2] + 1.5, length.out = 50)
 #' delta_grid <- delta_grid[delta_grid > 0]
 #' profile_ll_delta <- numeric(length(delta_grid))
-#' 
+#'
 #' for (i in seq_along(delta_grid)) {
 #'   profile_fit <- optim(
 #'     par = mle[1],
@@ -838,85 +858,95 @@ rbeta_ <- function(n, gamma = 1, delta = 0) {
 #'   )
 #'   profile_ll_delta[i] <- -profile_fit$value
 #' }
-#' 
+#'
 #' # 95% confidence threshold
 #' chi_crit <- qchisq(0.95, df = 1)
 #' threshold <- max(profile_ll_gamma) - chi_crit / 2
-#' 
-#' # Plot 
-#' 
-#' plot(gamma_grid, profile_ll_gamma, type = "l", lwd = 2, col = "#2E4057",
-#'      xlab = expression(gamma), ylab = "Profile Log-Likelihood",
-#'      main = expression(paste("Profile: ", gamma)), las = 1)
+#'
+#' # Plot
+#'
+#' plot(gamma_grid, profile_ll_gamma,
+#'   type = "l", lwd = 2, col = "#2E4057",
+#'   xlab = expression(gamma), ylab = "Profile Log-Likelihood",
+#'   main = expression(paste("Profile: ", gamma)), las = 1
+#' )
 #' abline(v = mle[1], col = "#8B0000", lty = 2, lwd = 2)
 #' abline(v = true_params[1], col = "#006400", lty = 2, lwd = 2)
 #' abline(h = threshold, col = "#808080", lty = 3, lwd = 1.5)
-#' legend("topright", legend = c("MLE", "True", "95% CI"),
-#'        col = c("#8B0000", "#006400", "#808080"),
-#'        lty = c(2, 2, 3), lwd = 2, bty = "n", cex = 0.8)
+#' legend("topright",
+#'   legend = c("MLE", "True", "95% CI"),
+#'   col = c("#8B0000", "#006400", "#808080"),
+#'   lty = c(2, 2, 3), lwd = 2, bty = "n", cex = 0.8
+#' )
 #' grid(col = "gray90")
-#' 
-#' plot(delta_grid, profile_ll_delta, type = "l", lwd = 2, col = "#2E4057",
-#'      xlab = expression(delta), ylab = "Profile Log-Likelihood",
-#'      main = expression(paste("Profile: ", delta)), las = 1)
+#'
+#' plot(delta_grid, profile_ll_delta,
+#'   type = "l", lwd = 2, col = "#2E4057",
+#'   xlab = expression(delta), ylab = "Profile Log-Likelihood",
+#'   main = expression(paste("Profile: ", delta)), las = 1
+#' )
 #' abline(v = mle[2], col = "#8B0000", lty = 2, lwd = 2)
 #' abline(v = true_params[2], col = "#006400", lty = 2, lwd = 2)
 #' abline(h = threshold, col = "#808080", lty = 3, lwd = 1.5)
-#' legend("topright", legend = c("MLE", "True", "95% CI"),
-#'        col = c("#8B0000", "#006400", "#808080"),
-#'        lty = c(2, 2, 3), lwd = 2, bty = "n", cex = 0.8)
+#' legend("topright",
+#'   legend = c("MLE", "True", "95% CI"),
+#'   col = c("#8B0000", "#006400", "#808080"),
+#'   lty = c(2, 2, 3), lwd = 2, bty = "n", cex = 0.8
+#' )
 #' grid(col = "gray90")
-#' 
-#' 
+#'
+#'
 #' ## Example 6: 2D Log-Likelihood Surface (Gamma vs Delta)
-#' 
+#'
 #' # Create 2D grid with wider range (±1.5)
-#' gamma_2d <- seq(mle[1] - 1.5, mle[1] + 1.5, length.out = round(n/25))
-#' delta_2d <- seq(mle[2] - 1.5, mle[2] + 1.5, length.out = round(n/25))
+#' gamma_2d <- seq(mle[1] - 1.5, mle[1] + 1.5, length.out = round(n / 25))
+#' delta_2d <- seq(mle[2] - 1.5, mle[2] + 1.5, length.out = round(n / 25))
 #' gamma_2d <- gamma_2d[gamma_2d > 0]
 #' delta_2d <- delta_2d[delta_2d > 0]
-#' 
+#'
 #' # Compute log-likelihood surface
 #' ll_surface_gd <- matrix(NA, nrow = length(gamma_2d), ncol = length(delta_2d))
-#' 
+#'
 #' for (i in seq_along(gamma_2d)) {
 #'   for (j in seq_along(delta_2d)) {
 #'     ll_surface_gd[i, j] <- -llbeta(c(gamma_2d[i], delta_2d[j]), data)
 #'   }
 #' }
-#' 
+#'
 #' # Confidence region levels
 #' max_ll_gd <- max(ll_surface_gd, na.rm = TRUE)
 #' levels_90_gd <- max_ll_gd - qchisq(0.90, df = 2) / 2
 #' levels_95_gd <- max_ll_gd - qchisq(0.95, df = 2) / 2
 #' levels_99_gd <- max_ll_gd - qchisq(0.99, df = 2) / 2
-#' 
+#'
 #' # Plot contour
-#' 
+#'
 #' contour(gamma_2d, delta_2d, ll_surface_gd,
-#'         xlab = expression(gamma), ylab = expression(delta),
-#'         main = "2D Log-Likelihood: Gamma vs Delta",
-#'         levels = seq(min(ll_surface_gd, na.rm = TRUE), max_ll_gd, length.out = 20),
-#'         col = "#2E4057", las = 1, lwd = 1)
-#' 
+#'   xlab = expression(gamma), ylab = expression(delta),
+#'   main = "2D Log-Likelihood: Gamma vs Delta",
+#'   levels = seq(min(ll_surface_gd, na.rm = TRUE), max_ll_gd, length.out = 20),
+#'   col = "#2E4057", las = 1, lwd = 1
+#' )
+#'
 #' contour(gamma_2d, delta_2d, ll_surface_gd,
-#'         levels = c(levels_90_gd, levels_95_gd, levels_99_gd),
-#'         col = c("#FFA07A", "#FF6347", "#8B0000"),
-#'         lwd = c(2, 2.5, 3), lty = c(3, 2, 1),
-#'         add = TRUE, labcex = 0.8)
-#' 
+#'   levels = c(levels_90_gd, levels_95_gd, levels_99_gd),
+#'   col = c("#FFA07A", "#FF6347", "#8B0000"),
+#'   lwd = c(2, 2.5, 3), lty = c(3, 2, 1),
+#'   add = TRUE, labcex = 0.8
+#' )
+#'
 #' points(mle[1], mle[2], pch = 19, col = "#8B0000", cex = 1.5)
 #' points(true_params[1], true_params[2], pch = 17, col = "#006400", cex = 1.5)
-#' 
+#'
 #' legend("topright",
-#'        legend = c("MLE", "True", "90% CR", "95% CR", "99% CR"),
-#'        col = c("#8B0000", "#006400", "#FFA07A", "#FF6347", "#8B0000"),
-#'        pch = c(19, 17, NA, NA, NA),
-#'        lty = c(NA, NA, 3, 2, 1),
-#'        lwd = c(NA, NA, 2, 2.5, 3),
-#'        bty = "n", cex = 0.8)
+#'   legend = c("MLE", "True", "90% CR", "95% CR", "99% CR"),
+#'   col = c("#8B0000", "#006400", "#FFA07A", "#FF6347", "#8B0000"),
+#'   pch = c(19, 17, NA, NA, NA),
+#'   lty = c(NA, NA, 3, 2, 1),
+#'   lwd = c(NA, NA, 2, 2.5, 3),
+#'   bty = "n", cex = 0.8
+#' )
 #' grid(col = "gray90")
-#' 
 #' }
 #'
 #' @export
@@ -934,12 +964,13 @@ llbeta <- function(par, data) {
   if (any(data <= 0 | data >= 1, na.rm = TRUE)) {
     warning("'data' contains values outside (0, 1)")
   }
-  
+
   # Call C++ implementation
-  .Call("_gkwdist_llbeta", 
-        as.numeric(par), 
-        as.numeric(data),
-        PACKAGE = "gkwdist")
+  .Call("_gkwdist_llbeta",
+    as.numeric(par),
+    as.numeric(data),
+    PACKAGE = "gkwdist"
+  )
 }
 
 
@@ -1014,41 +1045,41 @@ llbeta <- function(par, data) {
 #' @examples
 #' \donttest{
 #' ## Example 1: Basic Gradient Evaluation
-#' 
+#'
 #' # Generate sample data
 #' set.seed(123)
 #' n <- 1000
 #' true_params <- c(gamma = 2.0, delta = 3.0)
 #' data <- rbeta_(n, gamma = true_params[1], delta = true_params[2])
-#' 
+#'
 #' # Evaluate gradient at true parameters
 #' grad_true <- grbeta(par = true_params, data = data)
 #' cat("Gradient at true parameters:\n")
 #' print(grad_true)
 #' cat("Norm:", sqrt(sum(grad_true^2)), "\n")
-#' 
+#'
 #' # Evaluate at different parameter values
 #' test_params <- rbind(
 #'   c(1.5, 2.5),
 #'   c(2.0, 3.0),
 #'   c(2.5, 3.5)
 #' )
-#' 
+#'
 #' grad_norms <- apply(test_params, 1, function(p) {
 #'   g <- grbeta(p, data)
 #'   sqrt(sum(g^2))
 #' })
-#' 
+#'
 #' results <- data.frame(
 #'   Gamma = test_params[, 1],
 #'   Delta = test_params[, 2],
 #'   Grad_Norm = grad_norms
 #' )
 #' print(results, digits = 4)
-#' 
-#' 
+#'
+#'
 #' ## Example 2: Gradient in Optimization
-#' 
+#'
 #' # Optimization with analytical gradient
 #' fit_with_grad <- optim(
 #'   par = c(1.5, 2.5),
@@ -1061,7 +1092,7 @@ llbeta <- function(par, data) {
 #'   hessian = TRUE,
 #'   control = list(trace = 0)
 #' )
-#' 
+#'
 #' # Optimization without gradient
 #' fit_no_grad <- optim(
 #'   par = c(1.5, 2.5),
@@ -1073,7 +1104,7 @@ llbeta <- function(par, data) {
 #'   hessian = TRUE,
 #'   control = list(trace = 0)
 #' )
-#' 
+#'
 #' comparison <- data.frame(
 #'   Method = c("With Gradient", "Without Gradient"),
 #'   Gamma = c(fit_with_grad$par[1], fit_no_grad$par[1]),
@@ -1082,23 +1113,23 @@ llbeta <- function(par, data) {
 #'   Iterations = c(fit_with_grad$counts[1], fit_no_grad$counts[1])
 #' )
 #' print(comparison, digits = 4, row.names = FALSE)
-#' 
-#' 
+#'
+#'
 #' ## Example 3: Verifying Gradient at MLE
-#' 
+#'
 #' mle <- fit_with_grad$par
 #' names(mle) <- c("gamma", "delta")
-#' 
+#'
 #' # At MLE, gradient should be approximately zero
 #' gradient_at_mle <- grbeta(par = mle, data = data)
 #' cat("\nGradient at MLE:\n")
 #' print(gradient_at_mle)
 #' cat("Max absolute component:", max(abs(gradient_at_mle)), "\n")
 #' cat("Gradient norm:", sqrt(sum(gradient_at_mle^2)), "\n")
-#' 
-#' 
+#'
+#'
 #' ## Example 4: Numerical vs Analytical Gradient
-#' 
+#'
 #' # Manual finite difference gradient
 #' numerical_gradient <- function(f, x, data, h = 1e-7) {
 #'   grad <- numeric(length(x))
@@ -1110,51 +1141,51 @@ llbeta <- function(par, data) {
 #'   }
 #'   return(grad)
 #' }
-#' 
+#'
 #' # Compare at MLE
 #' grad_analytical <- grbeta(par = mle, data = data)
 #' grad_numerical <- numerical_gradient(llbeta, mle, data)
-#' 
+#'
 #' comparison_grad <- data.frame(
 #'   Parameter = c("gamma", "delta"),
 #'   Analytical = grad_analytical,
 #'   Numerical = grad_numerical,
 #'   Abs_Diff = abs(grad_analytical - grad_numerical),
 #'   Rel_Error = abs(grad_analytical - grad_numerical) /
-#'               (abs(grad_analytical) + 1e-10)
+#'     (abs(grad_analytical) + 1e-10)
 #' )
 #' print(comparison_grad, digits = 8)
-#' 
-#' 
+#'
+#'
 #' ## Example 5: Score Test Statistic
-#' 
+#'
 #' # Score test for H0: theta = theta0
 #' theta0 <- c(1.8, 2.8)
 #' score_theta0 <- -grbeta(par = theta0, data = data)
-#' 
+#'
 #' # Fisher information at theta0
 #' fisher_info <- hsbeta(par = theta0, data = data)
-#' 
+#'
 #' # Score test statistic
 #' score_stat <- t(score_theta0) %*% solve(fisher_info) %*% score_theta0
 #' p_value <- pchisq(score_stat, df = 2, lower.tail = FALSE)
-#' 
+#'
 #' cat("\nScore Test:\n")
 #' cat("H0: gamma=1.8, delta=2.8\n")
 #' cat("Test statistic:", score_stat, "\n")
 #' cat("P-value:", format.pval(p_value, digits = 4), "\n")
-#' 
-#' 
+#'
+#'
 #' ## Example 6: Confidence Ellipse (Gamma vs Delta)
-#' 
+#'
 #' # Observed information
 #' obs_info <- hsbeta(par = mle, data = data)
 #' vcov_full <- solve(obs_info)
-#' 
+#'
 #' # Create confidence ellipse
 #' theta <- seq(0, 2 * pi, length.out = 100)
 #' chi2_val <- qchisq(0.95, df = 2)
-#' 
+#'
 #' eig_decomp <- eigen(vcov_full)
 #' ellipse <- matrix(NA, nrow = 100, ncol = 2)
 #' for (i in 1:100) {
@@ -1162,34 +1193,36 @@ llbeta <- function(par, data) {
 #'   ellipse[i, ] <- mle + sqrt(chi2_val) *
 #'     (eig_decomp$vectors %*% diag(sqrt(eig_decomp$values)) %*% v)
 #' }
-#' 
+#'
 #' # Marginal confidence intervals
 #' se_2d <- sqrt(diag(vcov_full))
 #' ci_gamma <- mle[1] + c(-1, 1) * 1.96 * se_2d[1]
 #' ci_delta <- mle[2] + c(-1, 1) * 1.96 * se_2d[2]
-#' 
+#'
 #' # Plot
 #'
-#' plot(ellipse[, 1], ellipse[, 2], type = "l", lwd = 2, col = "#2E4057",
-#'      xlab = expression(gamma), ylab = expression(delta),
-#'      main = "95% Confidence Region (Gamma vs Delta)", las = 1)
-#' 
+#' plot(ellipse[, 1], ellipse[, 2],
+#'   type = "l", lwd = 2, col = "#2E4057",
+#'   xlab = expression(gamma), ylab = expression(delta),
+#'   main = "95% Confidence Region (Gamma vs Delta)", las = 1
+#' )
+#'
 #' # Add marginal CIs
 #' abline(v = ci_gamma, col = "#808080", lty = 3, lwd = 1.5)
 #' abline(h = ci_delta, col = "#808080", lty = 3, lwd = 1.5)
-#' 
+#'
 #' points(mle[1], mle[2], pch = 19, col = "#8B0000", cex = 1.5)
 #' points(true_params[1], true_params[2], pch = 17, col = "#006400", cex = 1.5)
-#' 
+#'
 #' legend("topright",
-#'        legend = c("MLE", "True", "95% CR", "Marginal 95% CI"),
-#'        col = c("#8B0000", "#006400", "#2E4057", "#808080"),
-#'        pch = c(19, 17, NA, NA),
-#'        lty = c(NA, NA, 1, 3),
-#'        lwd = c(NA, NA, 2, 1.5),
-#'        bty = "n")
+#'   legend = c("MLE", "True", "95% CR", "Marginal 95% CI"),
+#'   col = c("#8B0000", "#006400", "#2E4057", "#808080"),
+#'   pch = c(19, 17, NA, NA),
+#'   lty = c(NA, NA, 1, 3),
+#'   lwd = c(NA, NA, 2, 1.5),
+#'   bty = "n"
+#' )
 #' grid(col = "gray90")
-#' 
 #' }
 #'
 #' @export
@@ -1204,12 +1237,13 @@ grbeta <- function(par, data) {
   if (length(data) < 1) {
     stop("'data' must have at least one observation")
   }
-  
+
   # Call C++ implementation
-  .Call("_gkwdist_grbeta", 
-        as.numeric(par), 
-        as.numeric(data),
-        PACKAGE = "gkwdist")
+  .Call("_gkwdist_grbeta",
+    as.numeric(par),
+    as.numeric(data),
+    PACKAGE = "gkwdist"
+  )
 }
 
 
@@ -1289,25 +1323,27 @@ grbeta <- function(par, data) {
 #' @examples
 #' \donttest{
 #' ## Example 1: Basic Hessian Evaluation
-#' 
+#'
 #' # Generate sample data
 #' set.seed(123)
 #' n <- 1000
 #' true_params <- c(gamma = 2.0, delta = 3.0)
 #' data <- rbeta_(n, gamma = true_params[1], delta = true_params[2])
-#' 
+#'
 #' # Evaluate Hessian at true parameters
 #' hess_true <- hsbeta(par = true_params, data = data)
 #' cat("Hessian matrix at true parameters:\n")
 #' print(hess_true, digits = 4)
-#' 
+#'
 #' # Check symmetry
-#' cat("\nSymmetry check (max |H - H^T|):",
-#'     max(abs(hess_true - t(hess_true))), "\n")
-#' 
-#' 
+#' cat(
+#'   "\nSymmetry check (max |H - H^T|):",
+#'   max(abs(hess_true - t(hess_true))), "\n"
+#' )
+#'
+#'
 #' ## Example 2: Hessian Properties at MLE
-#' 
+#'
 #' # Fit model
 #' fit <- optim(
 #'   par = c(1.5, 2.5),
@@ -1319,48 +1355,50 @@ grbeta <- function(par, data) {
 #'   upper = c(100, 100),
 #'   hessian = TRUE
 #' )
-#' 
+#'
 #' mle <- fit$par
 #' names(mle) <- c("gamma", "delta")
-#' 
+#'
 #' # Hessian at MLE
 #' hessian_at_mle <- hsbeta(par = mle, data = data)
 #' cat("\nHessian at MLE:\n")
 #' print(hessian_at_mle, digits = 4)
-#' 
+#'
 #' # Compare with optim's numerical Hessian
 #' cat("\nComparison with optim Hessian:\n")
-#' cat("Max absolute difference:",
-#'     max(abs(hessian_at_mle - fit$hessian)), "\n")
-#' 
+#' cat(
+#'   "Max absolute difference:",
+#'   max(abs(hessian_at_mle - fit$hessian)), "\n"
+#' )
+#'
 #' # Eigenvalue analysis
 #' eigenvals <- eigen(hessian_at_mle, only.values = TRUE)$values
 #' cat("\nEigenvalues:\n")
 #' print(eigenvals)
-#' 
+#'
 #' cat("\nPositive definite:", all(eigenvals > 0), "\n")
 #' cat("Condition number:", max(eigenvals) / min(eigenvals), "\n")
-#' 
-#' 
+#'
+#'
 #' ## Example 3: Standard Errors and Confidence Intervals
-#' 
+#'
 #' # Observed information matrix
 #' obs_info <- hessian_at_mle
-#' 
+#'
 #' # Variance-covariance matrix
 #' vcov_matrix <- solve(obs_info)
 #' cat("\nVariance-Covariance Matrix:\n")
 #' print(vcov_matrix, digits = 6)
-#' 
+#'
 #' # Standard errors
 #' se <- sqrt(diag(vcov_matrix))
 #' names(se) <- c("gamma", "delta")
-#' 
+#'
 #' # Correlation matrix
 #' corr_matrix <- cov2cor(vcov_matrix)
 #' cat("\nCorrelation Matrix:\n")
 #' print(corr_matrix, digits = 4)
-#' 
+#'
 #' # Confidence intervals
 #' z_crit <- qnorm(0.975)
 #' results <- data.frame(
@@ -1372,15 +1410,19 @@ grbeta <- function(par, data) {
 #'   CI_Upper = mle + z_crit * se
 #' )
 #' print(results, digits = 4)
-#' 
-#' cat(sprintf("\nMLE corresponds approx to Beta(%.2f, %.2f)\n",
-#'     mle[1], mle[2] + 1))
-#' cat("True corresponds to Beta(%.2f, %.2f)\n",
-#'     true_params[1], true_params[2] + 1)
-#' 
-#' 
+#'
+#' cat(sprintf(
+#'   "\nMLE corresponds approx to Beta(%.2f, %.2f)\n",
+#'   mle[1], mle[2] + 1
+#' ))
+#' cat(
+#'   "True corresponds to Beta(%.2f, %.2f)\n",
+#'   true_params[1], true_params[2] + 1
+#' )
+#'
+#'
 #' ## Example 4: Determinant and Trace Analysis
-#' 
+#'
 #' # Compute at different points
 #' test_params <- rbind(
 #'   c(1.5, 2.5),
@@ -1388,7 +1430,7 @@ grbeta <- function(par, data) {
 #'   mle,
 #'   c(2.5, 3.5)
 #' )
-#' 
+#'
 #' hess_properties <- data.frame(
 #'   Gamma = numeric(),
 #'   Delta = numeric(),
@@ -1399,11 +1441,11 @@ grbeta <- function(par, data) {
 #'   Cond_Number = numeric(),
 #'   stringsAsFactors = FALSE
 #' )
-#' 
+#'
 #' for (i in 1:nrow(test_params)) {
 #'   H <- hsbeta(par = test_params[i, ], data = data)
 #'   eigs <- eigen(H, only.values = TRUE)$values
-#' 
+#'
 #'   hess_properties <- rbind(hess_properties, data.frame(
 #'     Gamma = test_params[i, 1],
 #'     Delta = test_params[i, 2],
@@ -1414,25 +1456,29 @@ grbeta <- function(par, data) {
 #'     Cond_Number = max(eigs) / min(eigs)
 #'   ))
 #' }
-#' 
+#'
 #' cat("\nHessian Properties at Different Points:\n")
 #' print(hess_properties, digits = 4, row.names = FALSE)
-#' 
-#' 
+#'
+#'
 #' ## Example 5: Curvature Visualization (Gamma vs Delta)
-#' 
+#'
 #' # Create grid around MLE
 #' gamma_grid <- seq(mle[1] - 1.5, mle[1] + 1.5, length.out = 25)
 #' delta_grid <- seq(mle[2] - 1.5, mle[2] + 1.5, length.out = 25)
 #' gamma_grid <- gamma_grid[gamma_grid > 0]
 #' delta_grid <- delta_grid[delta_grid > 0]
-#' 
+#'
 #' # Compute curvature measures
-#' determinant_surface <- matrix(NA, nrow = length(gamma_grid),
-#'                                ncol = length(delta_grid))
-#' trace_surface <- matrix(NA, nrow = length(gamma_grid),
-#'                          ncol = length(delta_grid))
-#' 
+#' determinant_surface <- matrix(NA,
+#'   nrow = length(gamma_grid),
+#'   ncol = length(delta_grid)
+#' )
+#' trace_surface <- matrix(NA,
+#'   nrow = length(gamma_grid),
+#'   ncol = length(delta_grid)
+#' )
+#'
 #' for (i in seq_along(gamma_grid)) {
 #'   for (j in seq_along(delta_grid)) {
 #'     H <- hsbeta(c(gamma_grid[i], delta_grid[j]), data)
@@ -1440,35 +1486,37 @@ grbeta <- function(par, data) {
 #'     trace_surface[i, j] <- sum(diag(H))
 #'   }
 #' }
-#' 
+#'
 #' # Plot
-#' 
+#'
 #' contour(gamma_grid, delta_grid, determinant_surface,
-#'         xlab = expression(gamma), ylab = expression(delta),
-#'         main = "Hessian Determinant", las = 1,
-#'         col = "#2E4057", lwd = 1.5, nlevels = 15)
+#'   xlab = expression(gamma), ylab = expression(delta),
+#'   main = "Hessian Determinant", las = 1,
+#'   col = "#2E4057", lwd = 1.5, nlevels = 15
+#' )
 #' points(mle[1], mle[2], pch = 19, col = "#8B0000", cex = 1.5)
 #' points(true_params[1], true_params[2], pch = 17, col = "#006400", cex = 1.5)
 #' grid(col = "gray90")
-#' 
+#'
 #' contour(gamma_grid, delta_grid, trace_surface,
-#'         xlab = expression(gamma), ylab = expression(delta),
-#'         main = "Hessian Trace", las = 1,
-#'         col = "#2E4057", lwd = 1.5, nlevels = 15)
+#'   xlab = expression(gamma), ylab = expression(delta),
+#'   main = "Hessian Trace", las = 1,
+#'   col = "#2E4057", lwd = 1.5, nlevels = 15
+#' )
 #' points(mle[1], mle[2], pch = 19, col = "#8B0000", cex = 1.5)
 #' points(true_params[1], true_params[2], pch = 17, col = "#006400", cex = 1.5)
 #' grid(col = "gray90")
-#' 
-#' 
+#'
+#'
 #' ## Example 6: Confidence Ellipse (Gamma vs Delta)
-#' 
+#'
 #' # Extract 2x2 submatrix (full matrix in this case)
 #' vcov_2d <- vcov_matrix
-#' 
+#'
 #' # Create confidence ellipse
 #' theta <- seq(0, 2 * pi, length.out = 100)
 #' chi2_val <- qchisq(0.95, df = 2)
-#' 
+#'
 #' eig_decomp <- eigen(vcov_2d)
 #' ellipse <- matrix(NA, nrow = 100, ncol = 2)
 #' for (i in 1:100) {
@@ -1476,34 +1524,36 @@ grbeta <- function(par, data) {
 #'   ellipse[i, ] <- mle + sqrt(chi2_val) *
 #'     (eig_decomp$vectors %*% diag(sqrt(eig_decomp$values)) %*% v)
 #' }
-#' 
+#'
 #' # Marginal confidence intervals
 #' se_2d <- sqrt(diag(vcov_2d))
 #' ci_gamma <- mle[1] + c(-1, 1) * 1.96 * se_2d[1]
 #' ci_delta <- mle[2] + c(-1, 1) * 1.96 * se_2d[2]
-#' 
+#'
 #' # Plot
 #'
-#' plot(ellipse[, 1], ellipse[, 2], type = "l", lwd = 2, col = "#2E4057",
-#'      xlab = expression(gamma), ylab = expression(delta),
-#'      main = "95% Confidence Ellipse (Gamma vs Delta)", las = 1)
-#' 
+#' plot(ellipse[, 1], ellipse[, 2],
+#'   type = "l", lwd = 2, col = "#2E4057",
+#'   xlab = expression(gamma), ylab = expression(delta),
+#'   main = "95% Confidence Ellipse (Gamma vs Delta)", las = 1
+#' )
+#'
 #' # Add marginal CIs
 #' abline(v = ci_gamma, col = "#808080", lty = 3, lwd = 1.5)
 #' abline(h = ci_delta, col = "#808080", lty = 3, lwd = 1.5)
-#' 
+#'
 #' points(mle[1], mle[2], pch = 19, col = "#8B0000", cex = 1.5)
 #' points(true_params[1], true_params[2], pch = 17, col = "#006400", cex = 1.5)
-#' 
+#'
 #' legend("topright",
-#'        legend = c("MLE", "True", "95% CR", "Marginal 95% CI"),
-#'        col = c("#8B0000", "#006400", "#2E4057", "#808080"),
-#'        pch = c(19, 17, NA, NA),
-#'        lty = c(NA, NA, 1, 3),
-#'        lwd = c(NA, NA, 2, 1.5),
-#'        bty = "n")
+#'   legend = c("MLE", "True", "95% CR", "Marginal 95% CI"),
+#'   col = c("#8B0000", "#006400", "#2E4057", "#808080"),
+#'   pch = c(19, 17, NA, NA),
+#'   lty = c(NA, NA, 1, 3),
+#'   lwd = c(NA, NA, 2, 1.5),
+#'   bty = "n"
+#' )
 #' grid(col = "gray90")
-#' 
 #' }
 #'
 #' @export
@@ -1518,10 +1568,11 @@ hsbeta <- function(par, data) {
   if (length(data) < 1) {
     stop("'data' must have at least one observation")
   }
-  
+
   # Call C++ implementation
-  .Call("_gkwdist_hsbeta", 
-        as.numeric(par), 
-        as.numeric(data),
-        PACKAGE = "gkwdist")
+  .Call("_gkwdist_hsbeta",
+    as.numeric(par),
+    as.numeric(data),
+    PACKAGE = "gkwdist"
+  )
 }
