@@ -1,7 +1,7 @@
 # ============================================================================#
 # KUMARASWAMY (Kw) DISTRIBUTION
 # ============================================================================#
-# 
+#
 # Wrapper functions for the two-parameter Kumaraswamy distribution.
 # C++ implementations are in src/kw.cpp
 #
@@ -93,21 +93,27 @@
 #' print(log(densities))
 #'
 #' # Compare with dgkw setting gamma = 1, delta = 0, lambda = 1
-#' densities_gkw <- dgkw(x_vals, alpha_par, beta_par, gamma = 1.0, delta = 0.0,
-#'                       lambda = 1.0)
+#' densities_gkw <- dgkw(x_vals, alpha_par, beta_par,
+#'   gamma = 1.0, delta = 0.0,
+#'   lambda = 1.0
+#' )
 #' print(paste("Max difference:", max(abs(densities - densities_gkw)))) # Should be near zero
 #'
 #' # Plot the density for different shape parameter combinations
 #' curve_x <- seq(0.001, 0.999, length.out = 200)
-#' plot(curve_x, dkw(curve_x, alpha = 2, beta = 3), type = "l",
-#'      main = "Kumaraswamy Density Examples", xlab = "x", ylab = "f(x)",
-#'      col = "blue", ylim = c(0, 4))
+#' plot(curve_x, dkw(curve_x, alpha = 2, beta = 3),
+#'   type = "l",
+#'   main = "Kumaraswamy Density Examples", xlab = "x", ylab = "f(x)",
+#'   col = "blue", ylim = c(0, 4)
+#' )
 #' lines(curve_x, dkw(curve_x, alpha = 3, beta = 2), col = "red")
 #' lines(curve_x, dkw(curve_x, alpha = 0.5, beta = 0.5), col = "green") # U-shaped
 #' lines(curve_x, dkw(curve_x, alpha = 5, beta = 1), col = "purple") # J-shaped
 #' lines(curve_x, dkw(curve_x, alpha = 1, beta = 3), col = "orange") # J-shaped (reversed)
-#' legend("top", legend = c("a=2, b=3", "a=3, b=2", "a=0.5, b=0.5", "a=5, b=1", "a=1, b=3"),
-#'        col = c("blue", "red", "green", "purple", "orange"), lty = 1, bty = "n", ncol = 2)
+#' legend("top",
+#'   legend = c("a=2, b=3", "a=3, b=2", "a=0.5, b=0.5", "a=5, b=1", "a=1, b=3"),
+#'   col = c("blue", "red", "green", "purple", "orange"), lty = 1, bty = "n", ncol = 2
+#' )
 #' }
 #' @export
 dkw <- function(x, alpha = 1, beta = 1, log = FALSE) {
@@ -122,14 +128,15 @@ dkw <- function(x, alpha = 1, beta = 1, log = FALSE) {
   if (!is.logical(log) || length(log) != 1) {
     stop("'log' must be a single logical value")
   }
-  
+
   # Call C++ implementation
-  .Call("_gkwdist_dkw", 
-        as.numeric(x), 
-        as.numeric(alpha), 
-        as.numeric(beta), 
-        as.logical(log),
-        PACKAGE = "gkwdist")
+  .Call("_gkwdist_dkw",
+    as.numeric(x),
+    as.numeric(alpha),
+    as.numeric(beta),
+    as.logical(log),
+    PACKAGE = "gkwdist"
+  )
 }
 
 
@@ -219,22 +226,27 @@ dkw <- function(x, alpha = 1, beta = 1, log = FALSE) {
 #' print(log(probs))
 #'
 #' # Compare with pgkw setting gamma = 1, delta = 0, lambda = 1
-#' probs_gkw <- pgkw(q_vals, alpha_par, beta_par, gamma = 1.0, delta = 0.0,
-#'                   lambda = 1.0)
+#' probs_gkw <- pgkw(q_vals, alpha_par, beta_par,
+#'   gamma = 1.0, delta = 0.0,
+#'   lambda = 1.0
+#' )
 #' print(paste("Max difference:", max(abs(probs - probs_gkw)))) # Should be near zero
 #'
 #' # Plot the CDF for different shape parameter combinations
 #' curve_q <- seq(0.001, 0.999, length.out = 200)
-#' plot(curve_q, pkw(curve_q, alpha = 2, beta = 3), type = "l",
-#'      main = "Kumaraswamy CDF Examples", xlab = "q", ylab = "F(q)",
-#'      col = "blue", ylim = c(0, 1))
+#' plot(curve_q, pkw(curve_q, alpha = 2, beta = 3),
+#'   type = "l",
+#'   main = "Kumaraswamy CDF Examples", xlab = "q", ylab = "F(q)",
+#'   col = "blue", ylim = c(0, 1)
+#' )
 #' lines(curve_q, pkw(curve_q, alpha = 3, beta = 2), col = "red")
 #' lines(curve_q, pkw(curve_q, alpha = 0.5, beta = 0.5), col = "green")
 #' lines(curve_q, pkw(curve_q, alpha = 5, beta = 1), col = "purple")
 #' lines(curve_q, pkw(curve_q, alpha = 1, beta = 3), col = "orange")
-#' legend("bottomright", legend = c("a=2, b=3", "a=3, b=2", "a=0.5, b=0.5", "a=5, b=1", "a=1, b=3"),
-#'        col = c("blue", "red", "green", "purple", "orange"), lty = 1, bty = "n", ncol = 2)
-#'
+#' legend("bottomright",
+#'   legend = c("a=2, b=3", "a=3, b=2", "a=0.5, b=0.5", "a=5, b=1", "a=1, b=3"),
+#'   col = c("blue", "red", "green", "purple", "orange"), lty = 1, bty = "n", ncol = 2
+#' )
 #' }
 #'
 #' @export
@@ -253,15 +265,16 @@ pkw <- function(q, alpha = 1, beta = 1, lower.tail = TRUE, log.p = FALSE) {
   if (!is.logical(log.p) || length(log.p) != 1) {
     stop("'log.p' must be a single logical value")
   }
-  
+
   # Call C++ implementation
-  .Call("_gkwdist_pkw", 
-        as.numeric(q), 
-        as.numeric(alpha), 
-        as.numeric(beta), 
-        as.logical(lower.tail),
-        as.logical(log.p),
-        PACKAGE = "gkwdist")
+  .Call("_gkwdist_pkw",
+    as.numeric(q),
+    as.numeric(alpha),
+    as.numeric(beta),
+    as.logical(lower.tail),
+    as.logical(log.p),
+    PACKAGE = "gkwdist"
+  )
 }
 
 
@@ -354,8 +367,10 @@ pkw <- function(q, alpha = 1, beta = 1, lower.tail = TRUE, log.p = FALSE) {
 #' print(quantiles)
 #'
 #' # Compare with qgkw setting gamma = 1, delta = 0, lambda = 1
-#' quantiles_gkw <- qgkw(p_vals, alpha = alpha_par, beta = beta_par,
-#'                      gamma = 1.0, delta = 0.0, lambda = 1.0)
+#' quantiles_gkw <- qgkw(p_vals,
+#'   alpha = alpha_par, beta = beta_par,
+#'   gamma = 1.0, delta = 0.0, lambda = 1.0
+#' )
 #' print(paste("Max difference:", max(abs(quantiles - quantiles_gkw)))) # Should be near zero
 #'
 #' # Verify inverse relationship with pkw
@@ -368,7 +383,6 @@ pkw <- function(q, alpha = 1, beta = 1, lower.tail = TRUE, log.p = FALSE) {
 #' # Boundary conditions
 #' print(qkw(c(0, 1), alpha_par, beta_par)) # Should be 0, 1
 #' print(qkw(c(-Inf, 0), alpha_par, beta_par, log.p = TRUE)) # Should be 0, 1
-#'
 #' }
 #'
 #' @export
@@ -387,20 +401,21 @@ qkw <- function(p, alpha = 1, beta = 1, lower.tail = TRUE, log.p = FALSE) {
   if (!is.logical(log.p) || length(log.p) != 1) {
     stop("'log.p' must be a single logical value")
   }
-  
+
   # Additional validation for probabilities
   if (!log.p && any(p < 0 | p > 1, na.rm = TRUE)) {
     warning("'p' values outside [0, 1] will produce NaN")
   }
-  
+
   # Call C++ implementation
-  .Call("_gkwdist_qkw", 
-        as.numeric(p), 
-        as.numeric(alpha), 
-        as.numeric(beta), 
-        as.logical(lower.tail),
-        as.logical(log.p),
-        PACKAGE = "gkwdist")
+  .Call("_gkwdist_qkw",
+    as.numeric(p),
+    as.numeric(alpha),
+    as.numeric(beta),
+    as.logical(lower.tail),
+    as.logical(log.p),
+    PACKAGE = "gkwdist"
+  )
 }
 
 
@@ -471,10 +486,13 @@ qkw <- function(p, alpha = 1, beta = 1, lower.tail = TRUE, log.p = FALSE) {
 #' summary(x_sample_kw)
 #'
 #' # Histogram of generated values compared to theoretical density
-#' hist(x_sample_kw, breaks = 30, freq = FALSE, # freq=FALSE for density
-#'      main = "Histogram of Kw Sample", xlab = "x", ylim = c(0, 2.5))
+#' hist(x_sample_kw,
+#'   breaks = 30, freq = FALSE, # freq=FALSE for density
+#'   main = "Histogram of Kw Sample", xlab = "x", ylim = c(0, 2.5)
+#' )
 #' curve(dkw(x, alpha = alpha_par, beta = beta_par),
-#'       add = TRUE, col = "red", lwd = 2, n = 201)
+#'   add = TRUE, col = "red", lwd = 2, n = 201
+#' )
 #' legend("top", legend = "Theoretical PDF", col = "red", lwd = 2, bty = "n")
 #'
 #' # Comparing empirical and theoretical quantiles (Q-Q plot)
@@ -482,20 +500,23 @@ qkw <- function(p, alpha = 1, beta = 1, lower.tail = TRUE, log.p = FALSE) {
 #' theo_quantiles <- qkw(prob_points, alpha = alpha_par, beta = beta_par)
 #' emp_quantiles <- quantile(x_sample_kw, prob_points, type = 7)
 #'
-#' plot(theo_quantiles, emp_quantiles, pch = 16, cex = 0.8,
-#'      main = "Q-Q Plot for Kw Distribution",
-#'      xlab = "Theoretical Quantiles", ylab = "Empirical Quantiles (n=1000)")
+#' plot(theo_quantiles, emp_quantiles,
+#'   pch = 16, cex = 0.8,
+#'   main = "Q-Q Plot for Kw Distribution",
+#'   xlab = "Theoretical Quantiles", ylab = "Empirical Quantiles (n=1000)"
+#' )
 #' abline(a = 0, b = 1, col = "blue", lty = 2)
 #'
 #' # Compare summary stats with rgkw(..., gamma=1, delta=0, lambda=1)
 #' # Note: individual values will differ due to randomness
-#' x_sample_gkw <- rgkw(1000, alpha = alpha_par, beta = beta_par, gamma = 1.0,
-#'                      delta = 0.0, lambda = 1.0)
+#' x_sample_gkw <- rgkw(1000,
+#'   alpha = alpha_par, beta = beta_par, gamma = 1.0,
+#'   delta = 0.0, lambda = 1.0
+#' )
 #' print("Summary stats for rkw sample:")
 #' print(summary(x_sample_kw))
 #' print("Summary stats for rgkw(gamma=1, delta=0, lambda=1) sample:")
 #' print(summary(x_sample_gkw)) # Should be similar
-#'
 #' }
 #'
 #' @export
@@ -506,20 +527,21 @@ rkw <- function(n, alpha = 1, beta = 1) {
     stop("'n' must be a positive integer")
   }
   n <- as.integer(n)
-  
+
   if (!is.numeric(alpha) || any(alpha <= 0)) {
     stop("'alpha' must be positive")
   }
   if (!is.numeric(beta) || any(beta <= 0)) {
     stop("'beta' must be positive")
   }
-  
+
   # Call C++ implementation
-  .Call("_gkwdist_rkw", 
-        as.integer(n), 
-        as.numeric(alpha), 
-        as.numeric(beta),
-        PACKAGE = "gkwdist")
+  .Call("_gkwdist_rkw",
+    as.integer(n),
+    as.numeric(alpha),
+    as.numeric(beta),
+    PACKAGE = "gkwdist"
+  )
 }
 
 
@@ -589,13 +611,13 @@ rkw <- function(n, alpha = 1, beta = 1) {
 #' @examples
 #' \donttest{
 #' ## Example 1: Maximum Likelihood Estimation with Analytical Gradient
-#' 
+#'
 #' # Generate sample data
 #' set.seed(123)
 #' n <- 1000
 #' true_params <- c(alpha = 2.5, beta = 3.5)
 #' data <- rkw(n, alpha = true_params[1], beta = true_params[2])
-#' 
+#'
 #' # Optimization using BFGS with analytical gradient
 #' fit <- optim(
 #'   par = c(2, 2),
@@ -605,14 +627,14 @@ rkw <- function(n, alpha = 1, beta = 1) {
 #'   method = "BFGS",
 #'   hessian = TRUE
 #' )
-#' 
+#'
 #' # Extract results
 #' mle <- fit$par
 #' names(mle) <- c("alpha", "beta")
 #' se <- sqrt(diag(solve(fit$hessian)))
 #' ci_lower <- mle - 1.96 * se
 #' ci_upper <- mle + 1.96 * se
-#' 
+#'
 #' # Summary table
 #' results <- data.frame(
 #'   Parameter = c("alpha", "beta"),
@@ -623,34 +645,34 @@ rkw <- function(n, alpha = 1, beta = 1) {
 #'   CI_Upper = ci_upper
 #' )
 #' print(results, digits = 4)
-#' 
+#'
 #' ## Example 2: Verifying Gradient at MLE
-#' 
+#'
 #' # At MLE, gradient should be approximately zero
 #' gradient_at_mle <- grkw(par = mle, data = data)
 #' print(gradient_at_mle)
 #' cat("Max absolute score:", max(abs(gradient_at_mle)), "\n")
-#' 
+#'
 #' ## Example 3: Checking Hessian Properties
-#' 
+#'
 #' # Hessian at MLE
 #' hessian_at_mle <- hskw(par = mle, data = data)
 #' print(hessian_at_mle, digits = 4)
-#' 
+#'
 #' # Check positive definiteness via eigenvalues
 #' eigenvals <- eigen(hessian_at_mle, only.values = TRUE)$values
 #' print(eigenvals)
 #' all(eigenvals > 0)
-#' 
+#'
 #' # Condition number
 #' cond_number <- max(eigenvals) / min(eigenvals)
 #' cat("Condition number:", format(cond_number, scientific = TRUE), "\n")
-#' 
+#'
 #' ## Example 4: Comparing Optimization Methods
-#' 
+#'
 #' methods <- c("BFGS", "L-BFGS-B", "Nelder-Mead", "CG")
 #' start_params <- c(2, 2)
-#' 
+#'
 #' comparison <- data.frame(
 #'   Method = character(),
 #'   Alpha_Est = numeric(),
@@ -659,7 +681,7 @@ rkw <- function(n, alpha = 1, beta = 1) {
 #'   Convergence = integer(),
 #'   stringsAsFactors = FALSE
 #' )
-#' 
+#'
 #' for (method in methods) {
 #'   if (method %in% c("BFGS", "CG")) {
 #'     fit_temp <- optim(
@@ -687,7 +709,7 @@ rkw <- function(n, alpha = 1, beta = 1) {
 #'       method = method
 #'     )
 #'   }
-#'   
+#'
 #'   comparison <- rbind(comparison, data.frame(
 #'     Method = method,
 #'     Alpha_Est = fit_temp$par[1],
@@ -697,19 +719,19 @@ rkw <- function(n, alpha = 1, beta = 1) {
 #'     stringsAsFactors = FALSE
 #'   ))
 #' }
-#' 
+#'
 #' print(comparison, digits = 4, row.names = FALSE)
-#' 
+#'
 #' ## Example 5: Likelihood Ratio Test
-#' 
+#'
 #' # Test H0: beta = 3 vs H1: beta free
 #' loglik_full <- -fit$value
-#' 
+#'
 #' # Restricted model: fix beta = 3
 #' restricted_ll <- function(alpha, data, beta_fixed) {
 #'   llkw(par = c(alpha, beta_fixed), data = data)
 #' }
-#' 
+#'
 #' fit_restricted <- optimize(
 #'   f = restricted_ll,
 #'   interval = c(0.1, 10),
@@ -717,21 +739,21 @@ rkw <- function(n, alpha = 1, beta = 1) {
 #'   beta_fixed = 3,
 #'   maximum = FALSE
 #' )
-#' 
+#'
 #' loglik_restricted <- -fit_restricted$objective
 #' lr_stat <- 2 * (loglik_full - loglik_restricted)
 #' p_value <- pchisq(lr_stat, df = 1, lower.tail = FALSE)
-#' 
+#'
 #' cat("LR Statistic:", round(lr_stat, 4), "\n")
 #' cat("P-value:", format.pval(p_value, digits = 4), "\n")
-#' 
+#'
 #' ## Example 6: Univariate Profile Likelihoods
-#' 
+#'
 #' # Grid for alpha
 #' alpha_grid <- seq(mle[1] - 1.5, mle[1] + 1.5, length.out = 50)
 #' alpha_grid <- alpha_grid[alpha_grid > 0]
 #' profile_ll_alpha <- numeric(length(alpha_grid))
-#' 
+#'
 #' for (i in seq_along(alpha_grid)) {
 #'   profile_fit <- optimize(
 #'     f = function(beta) llkw(c(alpha_grid[i], beta), data),
@@ -740,12 +762,12 @@ rkw <- function(n, alpha = 1, beta = 1) {
 #'   )
 #'   profile_ll_alpha[i] <- -profile_fit$objective
 #' }
-#' 
+#'
 #' # Grid for beta
 #' beta_grid <- seq(mle[2] - 1.5, mle[2] + 1.5, length.out = 50)
 #' beta_grid <- beta_grid[beta_grid > 0]
 #' profile_ll_beta <- numeric(length(beta_grid))
-#' 
+#'
 #' for (i in seq_along(beta_grid)) {
 #'   profile_fit <- optimize(
 #'     f = function(alpha) llkw(c(alpha, beta_grid[i]), data),
@@ -754,124 +776,139 @@ rkw <- function(n, alpha = 1, beta = 1) {
 #'   )
 #'   profile_ll_beta[i] <- -profile_fit$objective
 #' }
-#' 
+#'
 #' # 95% confidence threshold
 #' chi_crit <- qchisq(0.95, df = 1)
 #' threshold <- max(profile_ll_alpha) - chi_crit / 2
-#' 
-#' # Plot 
-#' 
+#'
+#' # Plot
+#'
 #' # Profile for alpha
-#' plot(alpha_grid, profile_ll_alpha, type = "l", lwd = 2, col = "#2E4057",
-#'      xlab = expression(alpha), ylab = "Profile Log-Likelihood",
-#'      main = expression(paste("Profile Likelihood: ", alpha)), las = 1)
+#' plot(alpha_grid, profile_ll_alpha,
+#'   type = "l", lwd = 2, col = "#2E4057",
+#'   xlab = expression(alpha), ylab = "Profile Log-Likelihood",
+#'   main = expression(paste("Profile Likelihood: ", alpha)), las = 1
+#' )
 #' abline(v = mle[1], col = "#8B0000", lty = 2, lwd = 2)
 #' abline(v = true_params[1], col = "#006400", lty = 2, lwd = 2)
 #' abline(h = threshold, col = "#808080", lty = 3, lwd = 1.5)
 #' legend("topright",
-#'        legend = c("MLE", "True", "95% CI"),
-#'        col = c("#8B0000", "#006400", "#808080"),
-#'        lty = c(2, 2, 3), lwd = 2, bty = "n", cex = 0.8)
+#'   legend = c("MLE", "True", "95% CI"),
+#'   col = c("#8B0000", "#006400", "#808080"),
+#'   lty = c(2, 2, 3), lwd = 2, bty = "n", cex = 0.8
+#' )
 #' grid(col = "gray90")
-#' 
+#'
 #' # Profile for beta
-#' plot(beta_grid, profile_ll_beta, type = "l", lwd = 2, col = "#2E4057",
-#'      xlab = expression(beta), ylab = "Profile Log-Likelihood",
-#'      main = expression(paste("Profile Likelihood: ", beta)), las = 1)
+#' plot(beta_grid, profile_ll_beta,
+#'   type = "l", lwd = 2, col = "#2E4057",
+#'   xlab = expression(beta), ylab = "Profile Log-Likelihood",
+#'   main = expression(paste("Profile Likelihood: ", beta)), las = 1
+#' )
 #' abline(v = mle[2], col = "#8B0000", lty = 2, lwd = 2)
 #' abline(v = true_params[2], col = "#006400", lty = 2, lwd = 2)
 #' abline(h = threshold, col = "#808080", lty = 3, lwd = 1.5)
 #' legend("topright",
-#'        legend = c("MLE", "True", "95% CI"),
-#'        col = c("#8B0000", "#006400", "#808080"),
-#'        lty = c(2, 2, 3), lwd = 2, bty = "n", cex = 0.8)
+#'   legend = c("MLE", "True", "95% CI"),
+#'   col = c("#8B0000", "#006400", "#808080"),
+#'   lty = c(2, 2, 3), lwd = 2, bty = "n", cex = 0.8
+#' )
 #' grid(col = "gray90")
-#' 
+#'
 #' ## Example 7: 2D Profile Likelihood Surface
-#' 
+#'
 #' # Create 2D grid
-#' alpha_2d <- seq(mle[1] - 1, mle[1] + 1, length.out = round(n/4))
-#' beta_2d <- seq(mle[2] - 1, mle[2] + 1, length.out = round(n/4))
+#' alpha_2d <- seq(mle[1] - 1, mle[1] + 1, length.out = round(n / 4))
+#' beta_2d <- seq(mle[2] - 1, mle[2] + 1, length.out = round(n / 4))
 #' alpha_2d <- alpha_2d[alpha_2d > 0]
 #' beta_2d <- beta_2d[beta_2d > 0]
-#' 
+#'
 #' # Compute log-likelihood surface
 #' ll_surface <- matrix(NA, nrow = length(alpha_2d), ncol = length(beta_2d))
-#' 
+#'
 #' for (i in seq_along(alpha_2d)) {
 #'   for (j in seq_along(beta_2d)) {
 #'     ll_surface[i, j] <- -llkw(c(alpha_2d[i], beta_2d[j]), data)
 #'   }
 #' }
-#' 
+#'
 #' # Confidence region levels
 #' max_ll <- max(ll_surface, na.rm = TRUE)
 #' levels_90 <- max_ll - qchisq(0.90, df = 2) / 2
 #' levels_95 <- max_ll - qchisq(0.95, df = 2) / 2
 #' levels_99 <- max_ll - qchisq(0.99, df = 2) / 2
-#' 
+#'
 #' # Plot contour
 #' contour(alpha_2d, beta_2d, ll_surface,
-#'         xlab = expression(alpha), ylab = expression(beta),
-#'         main = "2D Profile Log-Likelihood",
-#'         levels = seq(min(ll_surface, na.rm = TRUE), max_ll, length.out = round(n/4)),
-#'         col = "#2E4057", las = 1, lwd = 1)
-#' 
+#'   xlab = expression(alpha), ylab = expression(beta),
+#'   main = "2D Profile Log-Likelihood",
+#'   levels = seq(min(ll_surface, na.rm = TRUE), max_ll, length.out = round(n / 4)),
+#'   col = "#2E4057", las = 1, lwd = 1
+#' )
+#'
 #' # Add confidence region contours
 #' contour(alpha_2d, beta_2d, ll_surface,
-#'         levels = c(levels_90, levels_95, levels_99),
-#'         col = c("#FFA07A", "#FF6347", "#8B0000"),
-#'         lwd = c(2, 2.5, 3), lty = c(3, 2, 1),
-#'         add = TRUE, labcex = 0.8)
-#' 
+#'   levels = c(levels_90, levels_95, levels_99),
+#'   col = c("#FFA07A", "#FF6347", "#8B0000"),
+#'   lwd = c(2, 2.5, 3), lty = c(3, 2, 1),
+#'   add = TRUE, labcex = 0.8
+#' )
+#'
 #' # Mark points
 #' points(mle[1], mle[2], pch = 19, col = "#8B0000", cex = 1.5)
 #' points(true_params[1], true_params[2], pch = 17, col = "#006400", cex = 1.5)
-#' 
+#'
 #' legend("topright",
-#'        legend = c("MLE", "True", "90% CR", "95% CR", "99% CR"),
-#'        col = c("#8B0000", "#006400", "#FFA07A", "#FF6347", "#8B0000"),
-#'        pch = c(19, 17, NA, NA, NA),
-#'        lty = c(NA, NA, 3, 2, 1),
-#'        lwd = c(NA, NA, 2, 2.5, 3),
-#'        bty = "n", cex = 0.8)
+#'   legend = c("MLE", "True", "90% CR", "95% CR", "99% CR"),
+#'   col = c("#8B0000", "#006400", "#FFA07A", "#FF6347", "#8B0000"),
+#'   pch = c(19, 17, NA, NA, NA),
+#'   lty = c(NA, NA, 3, 2, 1),
+#'   lwd = c(NA, NA, 2, 2.5, 3),
+#'   bty = "n", cex = 0.8
+#' )
 #' grid(col = "gray90")
-#' 
+#'
 #' ## Example 8: Combined View - Profiles with 2D Surface
-#' 
+#'
 #' # Top left: Profile for alpha
-#' plot(alpha_grid, profile_ll_alpha, type = "l", lwd = 2, col = "#2E4057",
-#'      xlab = expression(alpha), ylab = "Profile Log-Likelihood",
-#'      main = expression(paste("Profile: ", alpha)), las = 1)
+#' plot(alpha_grid, profile_ll_alpha,
+#'   type = "l", lwd = 2, col = "#2E4057",
+#'   xlab = expression(alpha), ylab = "Profile Log-Likelihood",
+#'   main = expression(paste("Profile: ", alpha)), las = 1
+#' )
 #' abline(v = mle[1], col = "#8B0000", lty = 2, lwd = 2)
 #' abline(v = true_params[1], col = "#006400", lty = 2, lwd = 2)
 #' abline(h = threshold, col = "#808080", lty = 3)
 #' grid(col = "gray90")
-#' 
+#'
 #' # Top right: Profile for beta
-#' plot(beta_grid, profile_ll_beta, type = "l", lwd = 2, col = "#2E4057",
-#'      xlab = expression(beta), ylab = "Profile Log-Likelihood",
-#'      main = expression(paste("Profile: ", beta)), las = 1)
+#' plot(beta_grid, profile_ll_beta,
+#'   type = "l", lwd = 2, col = "#2E4057",
+#'   xlab = expression(beta), ylab = "Profile Log-Likelihood",
+#'   main = expression(paste("Profile: ", beta)), las = 1
+#' )
 #' abline(v = mle[2], col = "#8B0000", lty = 2, lwd = 2)
 #' abline(v = true_params[2], col = "#006400", lty = 2, lwd = 2)
 #' abline(h = threshold, col = "#808080", lty = 3)
 #' grid(col = "gray90")
-#' 
+#'
 #' # Bottom left: 2D contour
 #' contour(alpha_2d, beta_2d, ll_surface,
-#'         xlab = expression(alpha), ylab = expression(beta),
-#'         main = "2D Log-Likelihood Surface",
-#'         levels = seq(min(ll_surface, na.rm = TRUE), max_ll, length.out = 15),
-#'         col = "#2E4057", las = 1, lwd = 1)
+#'   xlab = expression(alpha), ylab = expression(beta),
+#'   main = "2D Log-Likelihood Surface",
+#'   levels = seq(min(ll_surface, na.rm = TRUE), max_ll, length.out = 15),
+#'   col = "#2E4057", las = 1, lwd = 1
+#' )
 #' contour(alpha_2d, beta_2d, ll_surface,
-#'         levels = c(levels_95),
-#'         col = "#8B0000", lwd = 2.5, add = TRUE)
+#'   levels = c(levels_95),
+#'   col = "#8B0000", lwd = 2.5, add = TRUE
+#' )
 #' points(mle[1], mle[2], pch = 19, col = "#8B0000", cex = 1.5)
 #' points(true_params[1], true_params[2], pch = 17, col = "#006400", cex = 1.5)
 #' grid(col = "gray90")
-#' 
+#'
 #' ## Example 9: Numerical Gradient Verification
-#' 
+#'
 #' # Manual finite difference gradient
 #' numerical_gradient <- function(f, x, data, h = 1e-7) {
 #'   grad <- numeric(length(x))
@@ -883,11 +920,11 @@ rkw <- function(n, alpha = 1, beta = 1) {
 #'   }
 #'   return(grad)
 #' }
-#' 
+#'
 #' # Compare
 #' grad_analytical <- grkw(par = mle, data = data)
 #' grad_numerical <- numerical_gradient(llkw, mle, data)
-#' 
+#'
 #' comparison_grad <- data.frame(
 #'   Parameter = c("alpha", "beta"),
 #'   Analytical = grad_analytical,
@@ -895,12 +932,12 @@ rkw <- function(n, alpha = 1, beta = 1) {
 #'   Difference = abs(grad_analytical - grad_numerical)
 #' )
 #' print(comparison_grad, digits = 8)
-#' 
+#'
 #' ## Example 10: Bootstrap Confidence Intervals
-#' 
-#' n_boot <- round(n/4)
+#'
+#' n_boot <- round(n / 4)
 #' boot_estimates <- matrix(NA, nrow = n_boot, ncol = 2)
-#' 
+#'
 #' set.seed(456)
 #' for (b in 1:n_boot) {
 #'   boot_data <- rkw(n, alpha = mle[1], beta = mle[2])
@@ -916,35 +953,42 @@ rkw <- function(n, alpha = 1, beta = 1) {
 #'     boot_estimates[b, ] <- boot_fit$par
 #'   }
 #' }
-#' 
+#'
 #' boot_estimates <- boot_estimates[complete.cases(boot_estimates), ]
 #' boot_ci <- apply(boot_estimates, 2, quantile, probs = c(0.025, 0.975))
 #' colnames(boot_ci) <- c("alpha", "beta")
-#' 
+#'
 #' print(t(boot_ci), digits = 4)
-#' 
+#'
 #' # Plot bootstrap distributions
-#' 
-#' hist(boot_estimates[, 1], breaks = 20, col = "#87CEEB", border = "white",
-#'      main = expression(paste("Bootstrap: ", hat(alpha))),
-#'      xlab = expression(hat(alpha)), las = 1)
+#'
+#' hist(boot_estimates[, 1],
+#'   breaks = 20, col = "#87CEEB", border = "white",
+#'   main = expression(paste("Bootstrap: ", hat(alpha))),
+#'   xlab = expression(hat(alpha)), las = 1
+#' )
 #' abline(v = mle[1], col = "#8B0000", lwd = 2)
 #' abline(v = true_params[1], col = "#006400", lwd = 2, lty = 2)
 #' abline(v = boot_ci[, 1], col = "#2E4057", lwd = 2, lty = 3)
-#' legend("topright", legend = c("MLE", "True", "95% CI"),
-#'        col = c("#8B0000", "#006400", "#2E4057"),
-#'        lwd = 2, lty = c(1, 2, 3), bty = "n")
-#' 
-#' hist(boot_estimates[, 2], breaks = 20, col = "#FFA07A", border = "white",
-#'      main = expression(paste("Bootstrap: ", hat(beta))),
-#'      xlab = expression(hat(beta)), las = 1)
+#' legend("topright",
+#'   legend = c("MLE", "True", "95% CI"),
+#'   col = c("#8B0000", "#006400", "#2E4057"),
+#'   lwd = 2, lty = c(1, 2, 3), bty = "n"
+#' )
+#'
+#' hist(boot_estimates[, 2],
+#'   breaks = 20, col = "#FFA07A", border = "white",
+#'   main = expression(paste("Bootstrap: ", hat(beta))),
+#'   xlab = expression(hat(beta)), las = 1
+#' )
 #' abline(v = mle[2], col = "#8B0000", lwd = 2)
 #' abline(v = true_params[2], col = "#006400", lwd = 2, lty = 2)
 #' abline(v = boot_ci[, 2], col = "#2E4057", lwd = 2, lty = 3)
-#' legend("topright", legend = c("MLE", "True", "95% CI"),
-#'        col = c("#8B0000", "#006400", "#2E4057"),
-#'        lwd = 2, lty = c(1, 2, 3), bty = "n")
-#' 
+#' legend("topright",
+#'   legend = c("MLE", "True", "95% CI"),
+#'   col = c("#8B0000", "#006400", "#2E4057"),
+#'   lwd = 2, lty = c(1, 2, 3), bty = "n"
+#' )
 #' }
 #'
 #' @export
@@ -959,12 +1003,13 @@ llkw <- function(par, data) {
   if (length(data) < 1) {
     stop("'data' must have at least one observation")
   }
-  
+
   # Call C++ implementation
-  .Call("_gkwdist_llkw", 
-        as.numeric(par), 
-        as.numeric(data),
-        PACKAGE = "gkwdist")
+  .Call("_gkwdist_llkw",
+    as.numeric(par),
+    as.numeric(data),
+    PACKAGE = "gkwdist"
+  )
 }
 
 
@@ -1033,19 +1078,19 @@ llkw <- function(par, data) {
 #' @examples
 #' \donttest{
 #' ## Example 1: Basic Gradient Evaluation
-#' 
+#'
 #' # Generate sample data
 #' set.seed(123)
 #' n <- 1000
 #' true_params <- c(alpha = 2.5, beta = 3.5)
 #' data <- rkw(n, alpha = true_params[1], beta = true_params[2])
-#' 
+#'
 #' # Evaluate gradient at true parameters
 #' grad_true <- grkw(par = true_params, data = data)
 #' cat("Gradient at true parameters:\n")
 #' print(grad_true)
 #' cat("Norm:", sqrt(sum(grad_true^2)), "\n")
-#' 
+#'
 #' # Evaluate at different parameter values
 #' test_params <- rbind(
 #'   c(1.5, 2.5),
@@ -1053,22 +1098,22 @@ llkw <- function(par, data) {
 #'   c(2.5, 3.5),
 #'   c(3.0, 4.0)
 #' )
-#' 
+#'
 #' grad_norms <- apply(test_params, 1, function(p) {
 #'   g <- grkw(p, data)
 #'   sqrt(sum(g^2))
 #' })
-#' 
+#'
 #' results <- data.frame(
 #'   Alpha = test_params[, 1],
 #'   Beta = test_params[, 2],
 #'   Grad_Norm = grad_norms
 #' )
 #' print(results, digits = 4)
-#' 
-#' 
+#'
+#'
 #' ## Example 2: Gradient in Optimization
-#' 
+#'
 #' # Optimization with analytical gradient
 #' fit_with_grad <- optim(
 #'   par = c(2, 2),
@@ -1079,7 +1124,7 @@ llkw <- function(par, data) {
 #'   hessian = TRUE,
 #'   control = list(trace = 0)
 #' )
-#' 
+#'
 #' # Optimization without gradient
 #' fit_no_grad <- optim(
 #'   par = c(2, 2),
@@ -1089,7 +1134,7 @@ llkw <- function(par, data) {
 #'   hessian = TRUE,
 #'   control = list(trace = 0)
 #' )
-#' 
+#'
 #' comparison <- data.frame(
 #'   Method = c("With Gradient", "Without Gradient"),
 #'   Alpha = c(fit_with_grad$par[1], fit_no_grad$par[1]),
@@ -1098,23 +1143,23 @@ llkw <- function(par, data) {
 #'   Iterations = c(fit_with_grad$counts[1], fit_no_grad$counts[1])
 #' )
 #' print(comparison, digits = 4, row.names = FALSE)
-#' 
-#' 
+#'
+#'
 #' ## Example 3: Verifying Gradient at MLE
-#' 
+#'
 #' mle <- fit_with_grad$par
 #' names(mle) <- c("alpha", "beta")
-#' 
+#'
 #' # At MLE, gradient should be approximately zero
 #' gradient_at_mle <- grkw(par = mle, data = data)
 #' cat("\nGradient at MLE:\n")
 #' print(gradient_at_mle)
 #' cat("Max absolute component:", max(abs(gradient_at_mle)), "\n")
 #' cat("Gradient norm:", sqrt(sum(gradient_at_mle^2)), "\n")
-#' 
-#' 
+#'
+#'
 #' ## Example 4: Numerical vs Analytical Gradient
-#' 
+#'
 #' # Manual finite difference gradient
 #' numerical_gradient <- function(f, x, data, h = 1e-7) {
 #'   grad <- numeric(length(x))
@@ -1126,7 +1171,7 @@ llkw <- function(par, data) {
 #'   }
 #'   return(grad)
 #' }
-#' 
+#'
 #' # Compare at several points
 #' test_points <- rbind(
 #'   c(1.5, 2.5),
@@ -1134,92 +1179,97 @@ llkw <- function(par, data) {
 #'   mle,
 #'   c(3.0, 4.0)
 #' )
-#' 
+#'
 #' cat("\nNumerical vs Analytical Gradient Comparison:\n")
 #' for (i in 1:nrow(test_points)) {
 #'   grad_analytical <- grkw(par = test_points[i, ], data = data)
 #'   grad_numerical <- numerical_gradient(llkw, test_points[i, ], data)
-#'   
-#'   cat("\nPoint", i, ": alpha =", test_points[i, 1], 
-#'       ", beta =", test_points[i, 2], "\n")
-#'   
+#'
+#'   cat(
+#'     "\nPoint", i, ": alpha =", test_points[i, 1],
+#'     ", beta =", test_points[i, 2], "\n"
+#'   )
+#'
 #'   comparison <- data.frame(
 #'     Parameter = c("alpha", "beta"),
 #'     Analytical = grad_analytical,
 #'     Numerical = grad_numerical,
 #'     Abs_Diff = abs(grad_analytical - grad_numerical),
-#'     Rel_Error = abs(grad_analytical - grad_numerical) / 
-#'                 (abs(grad_analytical) + 1e-10)
+#'     Rel_Error = abs(grad_analytical - grad_numerical) /
+#'       (abs(grad_analytical) + 1e-10)
 #'   )
 #'   print(comparison, digits = 8)
 #' }
-#' 
-#' 
+#'
+#'
 #' ## Example 5: Gradient Path Visualization
-#' 
+#'
 #' # Create grid
 #' alpha_grid <- seq(mle[1] - 1, mle[1] + 1, length.out = 20)
 #' beta_grid <- seq(mle[2] - 1, mle[2] + 1, length.out = 20)
 #' alpha_grid <- alpha_grid[alpha_grid > 0]
 #' beta_grid <- beta_grid[beta_grid > 0]
-#' 
+#'
 #' # Compute gradient vectors
 #' grad_alpha <- matrix(NA, nrow = length(alpha_grid), ncol = length(beta_grid))
 #' grad_beta <- matrix(NA, nrow = length(alpha_grid), ncol = length(beta_grid))
-#' 
+#'
 #' for (i in seq_along(alpha_grid)) {
 #'   for (j in seq_along(beta_grid)) {
 #'     g <- grkw(c(alpha_grid[i], beta_grid[j]), data)
-#'     grad_alpha[i, j] <- -g[1]  # Negative for gradient ascent
+#'     grad_alpha[i, j] <- -g[1] # Negative for gradient ascent
 #'     grad_beta[i, j] <- -g[2]
 #'   }
 #' }
-#' 
+#'
 #' # Plot gradient field
-#' 
-#' plot(mle[1], mle[2], pch = 19, col = "#8B0000", cex = 1.5,
-#'      xlim = range(alpha_grid), ylim = range(beta_grid),
-#'      xlab = expression(alpha), ylab = expression(beta),
-#'      main = "Gradient Vector Field", las = 1)
-#' 
+#'
+#' plot(mle[1], mle[2],
+#'   pch = 19, col = "#8B0000", cex = 1.5,
+#'   xlim = range(alpha_grid), ylim = range(beta_grid),
+#'   xlab = expression(alpha), ylab = expression(beta),
+#'   main = "Gradient Vector Field", las = 1
+#' )
+#'
 #' # Subsample for clearer visualization
 #' step <- 2
 #' for (i in seq(1, length(alpha_grid), by = step)) {
 #'   for (j in seq(1, length(beta_grid), by = step)) {
 #'     arrows(alpha_grid[i], beta_grid[j],
-#'            alpha_grid[i] + 0.05 * grad_alpha[i, j],
-#'            beta_grid[j] + 0.05 * grad_beta[i, j],
-#'            length = 0.05, col = "#2E4057", lwd = 1)
+#'       alpha_grid[i] + 0.05 * grad_alpha[i, j],
+#'       beta_grid[j] + 0.05 * grad_beta[i, j],
+#'       length = 0.05, col = "#2E4057", lwd = 1
+#'     )
 #'   }
 #' }
-#' 
+#'
 #' points(true_params[1], true_params[2], pch = 17, col = "#006400", cex = 1.5)
 #' legend("topright",
-#'        legend = c("MLE", "True"),
-#'        col = c("#8B0000", "#006400"),
-#'        pch = c(19, 17), bty = "n")
+#'   legend = c("MLE", "True"),
+#'   col = c("#8B0000", "#006400"),
+#'   pch = c(19, 17), bty = "n"
+#' )
 #' grid(col = "gray90")
-#' 
-#' 
+#'
+#'
 #' ## Example 6: Score Test Statistic
-#' 
+#'
 #' # Score test for H0: theta = theta0
 #' theta0 <- c(2, 3)
-#' score_theta0 <- -grkw(par = theta0, data = data)  # Score is negative gradient
-#' 
+#' score_theta0 <- -grkw(par = theta0, data = data) # Score is negative gradient
+#'
 #' # Fisher information at theta0 (using Hessian)
 #' fisher_info <- hskw(par = theta0, data = data)
-#' 
+#'
 #' # Score test statistic
 #' score_stat <- t(score_theta0) %*% solve(fisher_info) %*% score_theta0
 #' p_value <- pchisq(score_stat, df = 2, lower.tail = FALSE)
-#' 
+#'
 #' cat("\nScore Test:\n")
 #' cat("H0: alpha = 2, beta = 3\n")
 #' cat("Score vector:", score_theta0, "\n")
 #' cat("Test statistic:", score_stat, "\n")
 #' cat("P-value:", format.pval(p_value, digits = 4), "\n")
-#' 
 #' }
 #' @export
 grkw <- function(par, data) {
@@ -1233,12 +1283,13 @@ grkw <- function(par, data) {
   if (length(data) < 1) {
     stop("'data' must have at least one observation")
   }
-  
+
   # Call C++ implementation
-  .Call("_gkwdist_grkw", 
-        as.numeric(par), 
-        as.numeric(data),
-        PACKAGE = "gkwdist")
+  .Call("_gkwdist_grkw",
+    as.numeric(par),
+    as.numeric(data),
+    PACKAGE = "gkwdist"
+  )
 }
 
 
@@ -1321,24 +1372,26 @@ grkw <- function(par, data) {
 #' @examples
 #' \donttest{
 #' ## Example 1: Basic Hessian Evaluation
-#' 
+#'
 #' # Generate sample data
 #' set.seed(123)
 #' n <- 1000
 #' true_params <- c(alpha = 2.5, beta = 3.5)
 #' data <- rkw(n, alpha = true_params[1], beta = true_params[2])
-#' 
+#'
 #' # Evaluate Hessian at true parameters
 #' hess_true <- hskw(par = true_params, data = data)
 #' cat("Hessian matrix at true parameters:\n")
 #' print(hess_true, digits = 4)
-#' 
+#'
 #' # Check symmetry
-#' cat("\nSymmetry check (max |H - H^T|):",
-#'     max(abs(hess_true - t(hess_true))), "\n")
-#' 
+#' cat(
+#'   "\nSymmetry check (max |H - H^T|):",
+#'   max(abs(hess_true - t(hess_true))), "\n"
+#' )
+#'
 #' ## Example 2: Hessian Properties at MLE
-#' 
+#'
 #' # Fit model
 #' fit <- optim(
 #'   par = c(2, 2),
@@ -1348,48 +1401,50 @@ grkw <- function(par, data) {
 #'   method = "BFGS",
 #'   hessian = TRUE
 #' )
-#' 
+#'
 #' mle <- fit$par
 #' names(mle) <- c("alpha", "beta")
-#' 
+#'
 #' # Hessian at MLE
 #' hessian_at_mle <- hskw(par = mle, data = data)
 #' cat("\nHessian at MLE:\n")
 #' print(hessian_at_mle, digits = 4)
-#' 
+#'
 #' # Compare with optim's numerical Hessian
 #' cat("\nComparison with optim Hessian:\n")
-#' cat("Max absolute difference:",
-#'     max(abs(hessian_at_mle - fit$hessian)), "\n")
-#' 
+#' cat(
+#'   "Max absolute difference:",
+#'   max(abs(hessian_at_mle - fit$hessian)), "\n"
+#' )
+#'
 #' # Eigenvalue analysis
 #' eigenvals <- eigen(hessian_at_mle, only.values = TRUE)$values
 #' cat("\nEigenvalues:\n")
 #' print(eigenvals)
-#' 
+#'
 #' cat("\nPositive definite:", all(eigenvals > 0), "\n")
 #' cat("Condition number:", max(eigenvals) / min(eigenvals), "\n")
-#' 
-#' 
+#'
+#'
 #' ## Example 3: Standard Errors and Confidence Intervals
-#' 
+#'
 #' # Observed information matrix (negative Hessian for neg-loglik)
 #' obs_info <- hessian_at_mle
-#' 
+#'
 #' # Variance-covariance matrix
 #' vcov_matrix <- solve(obs_info)
 #' cat("\nVariance-Covariance Matrix:\n")
 #' print(vcov_matrix, digits = 6)
-#' 
+#'
 #' # Standard errors
 #' se <- sqrt(diag(vcov_matrix))
 #' names(se) <- c("alpha", "beta")
-#' 
+#'
 #' # Correlation matrix
 #' corr_matrix <- cov2cor(vcov_matrix)
 #' cat("\nCorrelation Matrix:\n")
 #' print(corr_matrix, digits = 4)
-#' 
+#'
 #' # Confidence intervals
 #' z_crit <- qnorm(0.975)
 #' results <- data.frame(
@@ -1401,9 +1456,9 @@ grkw <- function(par, data) {
 #'   CI_Upper = mle + z_crit * se
 #' )
 #' print(results, digits = 4)
-#' 
+#'
 #' ## Example 4: Determinant and Trace Analysis
-#' 
+#'
 #' # Compute at different points
 #' test_params <- rbind(
 #'   c(1.5, 2.5),
@@ -1411,7 +1466,7 @@ grkw <- function(par, data) {
 #'   mle,
 #'   c(3.0, 4.0)
 #' )
-#' 
+#'
 #' hess_properties <- data.frame(
 #'   Alpha = numeric(),
 #'   Beta = numeric(),
@@ -1422,11 +1477,11 @@ grkw <- function(par, data) {
 #'   Cond_Number = numeric(),
 #'   stringsAsFactors = FALSE
 #' )
-#' 
+#'
 #' for (i in 1:nrow(test_params)) {
 #'   H <- hskw(par = test_params[i, ], data = data)
 #'   eigs <- eigen(H, only.values = TRUE)$values
-#' 
+#'
 #'   hess_properties <- rbind(hess_properties, data.frame(
 #'     Alpha = test_params[i, 1],
 #'     Beta = test_params[i, 2],
@@ -1437,24 +1492,28 @@ grkw <- function(par, data) {
 #'     Cond_Number = max(eigs) / min(eigs)
 #'   ))
 #' }
-#' 
+#'
 #' cat("\nHessian Properties at Different Points:\n")
 #' print(hess_properties, digits = 4, row.names = FALSE)
-#' 
+#'
 #' ## Example 5: Curvature Visualization
-#' 
+#'
 #' # Create grid around MLE
 #' alpha_grid <- seq(mle[1] - 0.5, mle[1] + 0.5, length.out = 30)
 #' beta_grid <- seq(mle[2] - 0.5, mle[2] + 0.5, length.out = 30)
 #' alpha_grid <- alpha_grid[alpha_grid > 0]
 #' beta_grid <- beta_grid[beta_grid > 0]
-#' 
+#'
 #' # Compute curvature measures
-#' determinant_surface <- matrix(NA, nrow = length(alpha_grid),
-#'                                ncol = length(beta_grid))
-#' trace_surface <- matrix(NA, nrow = length(alpha_grid),
-#'                          ncol = length(beta_grid))
-#' 
+#' determinant_surface <- matrix(NA,
+#'   nrow = length(alpha_grid),
+#'   ncol = length(beta_grid)
+#' )
+#' trace_surface <- matrix(NA,
+#'   nrow = length(alpha_grid),
+#'   ncol = length(beta_grid)
+#' )
+#'
 #' for (i in seq_along(alpha_grid)) {
 #'   for (j in seq_along(beta_grid)) {
 #'     H <- hskw(c(alpha_grid[i], beta_grid[j]), data)
@@ -1462,49 +1521,51 @@ grkw <- function(par, data) {
 #'     trace_surface[i, j] <- sum(diag(H))
 #'   }
 #' }
-#' 
+#'
 #' # Plot
-#' 
+#'
 #' contour(alpha_grid, beta_grid, determinant_surface,
-#'         xlab = expression(alpha), ylab = expression(beta),
-#'         main = "Hessian Determinant", las = 1,
-#'         col = "#2E4057", lwd = 1.5, nlevels = 15)
+#'   xlab = expression(alpha), ylab = expression(beta),
+#'   main = "Hessian Determinant", las = 1,
+#'   col = "#2E4057", lwd = 1.5, nlevels = 15
+#' )
 #' points(mle[1], mle[2], pch = 19, col = "#8B0000", cex = 1.5)
 #' points(true_params[1], true_params[2], pch = 17, col = "#006400", cex = 1.5)
 #' grid(col = "gray90")
-#' 
+#'
 #' contour(alpha_grid, beta_grid, trace_surface,
-#'         xlab = expression(alpha), ylab = expression(beta),
-#'         main = "Hessian Trace", las = 1,
-#'         col = "#2E4057", lwd = 1.5, nlevels = 15)
+#'   xlab = expression(alpha), ylab = expression(beta),
+#'   main = "Hessian Trace", las = 1,
+#'   col = "#2E4057", lwd = 1.5, nlevels = 15
+#' )
 #' points(mle[1], mle[2], pch = 19, col = "#8B0000", cex = 1.5)
 #' points(true_params[1], true_params[2], pch = 17, col = "#006400", cex = 1.5)
 #' grid(col = "gray90")
-#' 
+#'
 #' ## Example 6: Fisher Information and Asymptotic Efficiency
-#' 
+#'
 #' # Observed information (at MLE)
 #' obs_fisher <- hessian_at_mle
-#' 
+#'
 #' # Asymptotic covariance matrix
 #' asymp_cov <- solve(obs_fisher)
-#' 
+#'
 #' cat("\nAsymptotic Standard Errors:\n")
 #' cat("SE(alpha):", sqrt(asymp_cov[1, 1]), "\n")
 #' cat("SE(beta):", sqrt(asymp_cov[2, 2]), "\n")
-#' 
+#'
 #' # Cramér-Rao Lower Bound
 #' cat("\nCramér-Rao Lower Bounds:\n")
 #' cat("CRLB(alpha):", sqrt(asymp_cov[1, 1]), "\n")
 #' cat("CRLB(beta):", sqrt(asymp_cov[2, 2]), "\n")
-#' 
+#'
 #' # Efficiency ellipse (95% confidence region)
 #' theta <- seq(0, 2 * pi, length.out = 100)
 #' chi2_val <- qchisq(0.95, df = 2)
-#' 
+#'
 #' # Eigendecomposition
 #' eig_decomp <- eigen(asymp_cov)
-#' 
+#'
 #' # Ellipse points
 #' ellipse <- matrix(NA, nrow = 100, ncol = 2)
 #' for (i in 1:100) {
@@ -1512,21 +1573,23 @@ grkw <- function(par, data) {
 #'   ellipse[i, ] <- mle + sqrt(chi2_val) *
 #'     (eig_decomp$vectors %*% diag(sqrt(eig_decomp$values)) %*% v)
 #' }
-#' 
+#'
 #' # Plot confidence ellipse
-#' 
-#' plot(ellipse[, 1], ellipse[, 2], type = "l", lwd = 2, col = "#2E4057",
-#'      xlab = expression(alpha), ylab = expression(beta),
-#'      main = "95% Confidence Ellipse", las = 1)
+#'
+#' plot(ellipse[, 1], ellipse[, 2],
+#'   type = "l", lwd = 2, col = "#2E4057",
+#'   xlab = expression(alpha), ylab = expression(beta),
+#'   main = "95% Confidence Ellipse", las = 1
+#' )
 #' points(mle[1], mle[2], pch = 19, col = "#8B0000", cex = 1.5)
 #' points(true_params[1], true_params[2], pch = 17, col = "#006400", cex = 1.5)
 #' legend("topright",
-#'        legend = c("MLE", "True", "95% CR"),
-#'        col = c("#8B0000", "#006400", "#2E4057"),
-#'        pch = c(19, 17, NA), lty = c(NA, NA, 1),
-#'        lwd = c(NA, NA, 2), bty = "n")
+#'   legend = c("MLE", "True", "95% CR"),
+#'   col = c("#8B0000", "#006400", "#2E4057"),
+#'   pch = c(19, 17, NA), lty = c(NA, NA, 1),
+#'   lwd = c(NA, NA, 2), bty = "n"
+#' )
 #' grid(col = "gray90")
-#' 
 #' }
 #'
 #' @export
@@ -1541,12 +1604,13 @@ hskw <- function(par, data) {
   if (length(data) < 1) {
     stop("'data' must have at least one observation")
   }
-  
+
   # Call C++ implementation
-  .Call("_gkwdist_hskw", 
-        as.numeric(par), 
-        as.numeric(data),
-        PACKAGE = "gkwdist")
+  .Call("_gkwdist_hskw",
+    as.numeric(par),
+    as.numeric(data),
+    PACKAGE = "gkwdist"
+  )
 }
 
 # ============================================================================#
